==> arna-0.2.6.tar.gz: example/lib/screens/widgets.dart <==
import 'package:arna/arna.dart';

class Widgets extends StatefulWidget {
  const Widgets({Key? key}) : super(key: key);

  @override
  _WidgetsState createState() => _WidgetsState();
}

class _WidgetsState extends State<Widgets> {
  var _selectedType = "1";
  bool _checkBox1 = false;
  bool? _checkBox2 = false;
  final bool _checkBox3 = false;
  bool _switch1 = false;
  bool _switch2 = false;
  final bool _switch3 = false;
  double _sliderValue = 50;
  int segmentedControlGroupValue = 0;

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      child: Column(
        children: [
          ArnaList(
            title: "Buttons",
            items: [
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  ArnaIconButton(
                    icon: Icons.add_outlined,
                    onPressed: () => showArnaSnackbar(
                      context: context,
                      message: "Hello There!",
                    ),
                    tooltipMessage: "Add",
                  ),
                  ArnaTextButton(
                    label: "Add",
                    onPressed: () => showArnaSnackbar(
                      context: context,
                      message: "Hello There!",
                    ),
                    tooltipMessage: "Add",
                  ),
                  ArnaButton(
                    label: "Add",
                    icon: Icons.add_outlined,
                    onPressed: () => showArnaSnackbar(
                      context: context,
                      message: "Hello There!",
                    ),
                    tooltipMessage: "Add",
                  ),
                  const ArnaButton(
                    label: "Add",
                    icon: Icons.add_outlined,
                    onPressed: null,
                    tooltipMessage: "Add",
                  ),
                  ArnaIconButton(
                    icon: Icons.add_outlined,
                    buttonType: ButtonType.suggested,
                    onPressed: () => showArnaSnackbar(
                      context: context,
                      message: "Hello There!",
                    ),
                    tooltipMessage: "Add",
                  ),
                ],
              ),
            ],
          ),
          ArnaList(
            title: "Linked Buttons",
            items: [
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  ArnaLinkedButtons(
                    buttons: [
                      ArnaLinkedButton(
                        icon: Icons.add_outlined,
                        onPressed: () => showArnaSnackbar(
                          context: context,
                          message: "Hello There!",
                        ),
                      ),
                      ArnaLinkedButton(
                        label: "Add",
                        onPressed: () => showArnaSnackbar(
                          context: context,
                          message: "Hello There!",
                        ),
                      ),
                      ArnaLinkedButton(
                        label: "Add",
                        icon: Icons.add_outlined,
                        onPressed: () => showArnaSnackbar(
                          context: context,
                          message: "Hello There!",
                        ),
                      ),
                      const ArnaLinkedButton(
                        label: "Add",
                        icon: Icons.add_outlined,
                        onPressed: null,
                      ),
                    ],
                  ),
                ],
              ),
            ],
          ),
          ArnaList(
            title: "Segmented Control",
            items: [
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  ArnaSegmentedControl(
                    groupValue: segmentedControlGroupValue,
                    children: const {0: "Item 1", 1: "Item 2", 2: "Item 3"},
                    onValueChanged: (int i) =>
                        setState(() => segmentedControlGroupValue = i),
                  ),
                ],
              ),
            ],
          ),
          ArnaList(
            title: "CheckBox",
            items: [
              ArnaCheckBoxListTile(
                value: _checkBox1,
                title: "CheckBox 1",
                onChanged: (value) => setState(() => _checkBox1 = value!),
              ),
              ArnaCheckBoxListTile(
                value: _checkBox2,
                title: "CheckBox 2",
                subtitle: "Subtitle 2",
                tristate: true,
                onChanged: (value) => setState(() => _checkBox2 = value),
                trailingButton: ArnaIconButton(
                  icon: Icons.add_outlined,
                  onPressed: () {},
                ),
              ),
              ArnaCheckBoxListTile(
                value: _checkBox3,
                title: "CheckBox 3",
                subtitle: "Subtitle 3",
                onChanged: null,
              ),
            ],
          ),
          ArnaList(
            title: "Radio",
            items: [
              ArnaRadioListTile(
                value: "1",
                groupValue: _selectedType,
                title: "Radio 1",
                onChanged: (value) =>
                    setState(() => _selectedType = value as String),
              ),
              ArnaRadioListTile(
                value: "2",
                groupValue: _selectedType,
                title: "Radio 2",
                subtitle: "Subtitle 2",
                onChanged: (value) =>
                    setState(() => _selectedType = value as String),
                trailingButton: ArnaIconButton(
                  icon: Icons.add_outlined,
                  onPressed: () {},
                ),
              ),
              ArnaRadioListTile(
                value: "3",
                groupValue: _selectedType,
                title: "Radio 3",
                subtitle: "Subtitle 3",
                onChanged: null,
              ),
            ],
          ),
          ArnaList(
            title: "Switch",
            items: [
              ArnaSwitchListTile(
                title: "Switch 1",
                value: _switch1,
                onChanged: (value) => setState(() => _switch1 = value),
              ),
              ArnaSwitchListTile(
                title: "Switch 2",
                subtitle: "Subtitle 2",
                value: _switch2,
                onChanged: (value) => setState(() => _switch2 = value),
                trailingButton: ArnaIconButton(
                  icon: Icons.add_outlined,
                  onPressed: () {},
                ),
              ),
              ArnaSwitchListTile(
                title: "Switch 3",
                subtitle: "Subtitle 3",
                value: _switch3,
                onChanged: null,
              ),
            ],
          ),
          ArnaList(
            title: "List Tile",
            items: [
              ArnaListTile(
                title: "Title 1",
                subtitle: "Subtitle 1",
                trailing: const ArnaBadge(label: "1"),
                onTap: () {},
              ),
              const ArnaListTile(
                title: "Title 2",
                subtitle: "Subtitle 2",
                trailing: ArnaBadge(label: "2"),
              ),
            ],
          ),
          const ArnaList(
            title: "Expansion Panel",
            items: [
              ArnaExpansionPanel(
                title: "Title 1",
                subtitle: "Subtitle 1",
                child: ArnaListTile(
                  title: "Title 2",
                  subtitle: "Subtitle 2",
                  trailing: ArnaBadge(label: "2"),
                ),
              ),
            ],
          ),
          ArnaList(
            title: "Slider",
            items: [
              ArnaSlider(
                value: _sliderValue,
                min: 0,
                max: 100,
                onChanged: (double newValue) {
                  setState(() => _sliderValue = newValue);
                },
              )
            ],
          ),
          const ArnaList(
            title: "Text Field",
            items: [
              Padding(
                padding: Styles.large,
                child: ArnaTextField(),
              )
            ],
          ),
        ],
      ),
    );
  }
}

==> arna-0.2.7.tar.gz: example/lib/screens/widgets.dart <==
import 'package:arna/arna.dart';

class Widgets extends StatefulWidget {
  const Widgets({Key? key}) : super(key: key);

  @override
  _WidgetsState createState() => _WidgetsState();
}

class _WidgetsState extends State<Widgets> {
  var _selectedType = "1";
  bool _checkBox1 = false;
  bool? _checkBox2 = false;
  final bool _checkBox3 = false;
  bool _switch1 = false;
  bool _switch2 = false;
  final bool _switch3 = false;
  double _sliderValue1 = 0;
  double _sliderValue2 = 0;
  final double _sliderValue3 = 0;
  int segmentedControlGroupValue = 0;

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      child: Column(
        children: [
          ArnaList(
            title: "Buttons",
            items: [
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  ArnaIconButton(
                    icon: Icons.add_outlined,
                    onPressed: () => showArnaSnackbar(
                      context: context,
                      message: "Hello There!",
                    ),
                    tooltipMessage: "Add",
                  ),
                  ArnaTextButton(
                    label: "Add",
                    onPressed: () => showArnaSnackbar(
                      context: context,
                      message: "Hello There!",
                    ),
                    tooltipMessage: "Add",
                  ),
                  ArnaButton(
                    label: "Add",
                    icon: Icons.add_outlined,
                    onPressed: () => showArnaSnackbar(
                      context: context,
                      message: "Hello There!",
                    ),
                    tooltipMessage: "Add",
                  ),
                  const ArnaButton(
                    label: "Add",
                    icon: Icons.add_outlined,
                    onPressed: null,
                    tooltipMessage: "Add",
                  ),
                  ArnaIconButton(
                    icon: Icons.add_outlined,
                    buttonType: ButtonType.suggested,
                    onPressed: () => showArnaSnackbar(
                      context: context,
                      message: "Hello There!",
                    ),
                    tooltipMessage: "Add",
                  ),
                ],
              ),
            ],
          ),
          ArnaList(
            title: "Linked Buttons",
            items: [
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  ArnaLinkedButtons(
                    buttons: [
                      ArnaLinkedButton(
                        icon: Icons.add_outlined,
                        onPressed: () => showArnaSnackbar(
                          context: context,
                          message: "Hello There!",
                        ),
                      ),
                      ArnaLinkedButton(
                        label: "Add",
                        onPressed: () => showArnaSnackbar(
                          context: context,
                          message: "Hello There!",
                        ),
                      ),
                      ArnaLinkedButton(
                        label: "Add",
                        icon: Icons.add_outlined,
                        onPressed: () => showArnaSnackbar(
                          context: context,
                          message: "Hello There!",
                        ),
                      ),
                      const ArnaLinkedButton(
                        label: "Add",
                        icon: Icons.add_outlined,
                        onPressed: null,
                      ),
                    ],
                  ),
                ],
              ),
            ],
          ),
          ArnaList(
            title: "Segmented Control",
            items: [
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  ArnaSegmentedControl(
                    groupValue: segmentedControlGroupValue,
                    children: const {0: "Item 1", 1: "Item 2", 2: "Item 3"},
                    onValueChanged: (int i) =>
                        setState(() => segmentedControlGroupValue = i),
                  ),
                ],
              ),
            ],
          ),
          ArnaList(
            title: "CheckBox",
            items: [
              ArnaCheckBoxListTile(
                value: _checkBox1,
                title: "CheckBox 1",
                onChanged: (value) => setState(() => _checkBox1 = value!),
              ),
              ArnaCheckBoxListTile(
                value: _checkBox2,
                title: "CheckBox 2",
                subtitle: "Subtitle 2",
                tristate: true,
                onChanged: (value) => setState(() => _checkBox2 = value),
                trailingButton: ArnaIconButton(
                  icon: Icons.add_outlined,
                  onPressed: () {},
                ),
              ),
              ArnaCheckBoxListTile(
                value: _checkBox3,
                title: "CheckBox 3",
                subtitle: "Subtitle 3",
                onChanged: null,
              ),
            ],
          ),
          ArnaList(
            title: "Radio",
            items: [
              ArnaRadioListTile(
                value: "1",
                groupValue: _selectedType,
                title: "Radio 1",
                onChanged: (value) =>
                    setState(() => _selectedType = value as String),
              ),
              ArnaRadioListTile(
                value: "2",
                groupValue: _selectedType,
                title: "Radio 2",
                subtitle: "Subtitle 2",
                onChanged: (value) =>
                    setState(() => _selectedType = value as String),
                trailingButton: ArnaIconButton(
                  icon: Icons.add_outlined,
                  onPressed: () {},
                ),
              ),
              ArnaRadioListTile(
                value: "3",
                groupValue: _selectedType,
                title: "Radio 3",
                subtitle: "Subtitle 3",
                onChanged: null,
              ),
            ],
          ),
          ArnaList(
            title: "Switch",
            items: [
              ArnaSwitchListTile(
                title: "Switch 1",
                value: _switch1,
                onChanged: (value) => setState(() => _switch1 = value),
              ),
              ArnaSwitchListTile(
                title: "Switch 2",
                subtitle: "Subtitle 2",
                value: _switch2,
                onChanged: (value) => setState(() => _switch2 = value),
                trailingButton: ArnaIconButton(
                  icon: Icons.add_outlined,
                  onPressed: () {},
                ),
              ),
              ArnaSwitchListTile(
                title: "Switch 3",
                subtitle: "Subtitle 3",
                value: _switch3,
                onChanged: null,
              ),
            ],
          ),
          ArnaList(
            title: "List Tile",
            items: [
              ArnaListTile(
                title: "Title 1",
                subtitle: "Subtitle 1",
                trailing: const ArnaBadge(label: "1"),
                onTap: () {},
              ),
              const ArnaListTile(
                title: "Title 2",
                subtitle: "Subtitle 2",
                trailing: ArnaBadge(label: "2"),
              ),
            ],
          ),
          const ArnaList(
            title: "Expansion Panel",
            items: [
              ArnaExpansionPanel(
                title: "Title 1",
                subtitle: "Subtitle 1",
                child: ArnaListTile(
                  title: "Title 2",
                  subtitle: "Subtitle 2",
                  trailing: ArnaBadge(label: "2"),
                ),
              ),
            ],
          ),
          ArnaList(
            title: "Slider",
            items: [
              ArnaSliderListTile(
                title: "Title 1",
                value: _sliderValue1,
                min: 0,
                max: 100,
                onChanged: (double newValue) =>
                    setState(() => _sliderValue1 = newValue),
              ),
              ArnaSliderListTile(
                title: "Title 2",
                subtitle: "Subtitle 2",
                value: _sliderValue2,
                min: 0,
                max: 100,
                onChanged: (double newValue) =>
                    setState(() => _sliderValue2 = newValue),
                trailingButton: ArnaIconButton(
                  icon: Icons.add_outlined,
                  onPressed: () {},
                ),
              ),
              ArnaSliderListTile(
                title: "Title 3",
                subtitle: "Subtitle 3",
                value: _sliderValue3,
                min: 0,
                max: 100,
                onChanged: null,
              ),
            ],
          ),
          const ArnaList(
            title: "Text Field",
            items: [
              Padding(
                padding: Styles.large,
                child: ArnaTextField(),
              )
            ],
          ),
        ],
      ),
    );
  }
}
